<?php
require_once __DIR__ . '/../../../init.php';
App::load_function('gateway');
App::load_function('invoice');

// Detect module name from filename.
$gatewayModuleName = basename(__FILE__, '.php');

// Fetch gateway configuration parameters.
$gatewayParams = getGatewayVariables($gatewayModuleName);

// Die if module is not active.
if (!$gatewayParams['type']) {
    die('Module Not Activated');
}

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    logTransaction($gatewayParams['name'], $_POST, 'Invalid method');
    http_response_code(405); // Method Not Allowed
    exit;
}

// Get the signature header
$signature_header = $_SERVER['HTTP_X_API_SHA256_SIGNATURE'] ?? '';

if (!$signature_header) {
    logTransaction($gatewayParams['name'], 'No signature header', 'Failure');
    exit;
}

$request_body = file_get_contents('php://input');
logTransaction($gatewayParams['name'], $request_body, 'Request body');

$sign = json_decode($request_body, true);
ksort($sign);
$sign = json_encode($sign);
$secret_key = $gatewayParams['secret_word2'];
$calculated_signature = hash_hmac('sha256', $sign, $secret_key);

// Compare the calculated signature with the signature in the header
if (!hash_equals($signature_header, $calculated_signature)) {
    logTransaction($gatewayParams['name'], 'Invalid signature', 'Failure');
    http_response_code(401); // Unauthorized
    exit;
}

$request_body = json_decode($request_body, true);
$order_id = $request_body['order_id'] ?? 0;

if (!$order_id) {
    logTransaction($gatewayParams['name'], 'Empty order_id', 'Failure');
    http_response_code(406);
    exit;
}

$order_id = explode('-', $request_body['order_id']);
$order_id = (int)$order_id[0] ?? 0;

if (!$order_id) {
    logTransaction($gatewayParams['name'], 'Incorrect order_id', 'Failure');
    http_response_code(406);
    exit;
}
checkCbTransID($order_id);

$status = $request_body['status'] ?? 'unknown';

if ($status != 'success') {
    logTransaction($gatewayParams['name'], "Unsuccessful status for order $order_id - $status", 'Failure');
    exit;
}

addInvoicePayment($order_id, $request_body['invoice_id'], 0, 0, $gatewayModuleName);
logTransaction($gatewayParams['name'], $request_body, 'Payment complete');