<?php
if (!defined("WHMCS")) {
	die("This file cannot be accessed directly");
}

/**
 * Define module related meta data.
 *
 * Values returned here are used to determine module related capabilities and
 * settings.
 *
 * @see https://developers.whmcs.com/payment-gateways/meta-data-params/
 *
 * @return array
 */
function morune_MetaData() {
	return array(
		'DisplayName' => 'Morune Merchant Gateway Module',
		'APIVersion' => '1.1', // Use API Version 1.1
		'DisableLocalCredtCardInput' => true,
		'TokenisedStorage' => false,
	);
}

/**
 * Define gateway configuration options.
 *
 * The fields you define here determine the configuration options that are
 * presented to administrator users when activating and configuring your
 * payment gateway module for use.
 *
 * Supported field types include:
 * * text
 * * password
 * * yesno
 * * dropdown
 * * radio
 * * textarea
 *
 * Examples of each field type and their possible configuration parameters are
 * provided in the sample function below.
 *
 * @see https://developers.whmcs.com/payment-gateways/configuration/
 *
 * @return array
 */
function morune_config() {
	return array(
		// the friendly display name for a payment gateway should be
		// defined here for backwards compatibility
		'FriendlyName' => array(
			'Type' => 'System',
			'Value' => 'Morune',
		),
		'merchant_id' => array(
			'FriendlyName' => 'ID магазина',
			'Type' => 'text',
			'Size' => '255',
			'Default' => '',
			'Description' => '',
		),
		'secret_word' => array(
			'FriendlyName' => 'Секретный пароль',
			'Type' => 'text',
			'Size' => '255',
			'Default' => '',
			'Description' => '',
		),
		'secret_word2' => array(
			'FriendlyName' => 'Дополнительный ключ',
			'Type' => 'text',
			'Size' => '255',
			'Default' => '',
			'Description' => '',
		),
	);
}

/**
 * Payment link.
 *
 * Required by third party payment gateway modules only.
 *
 * Defines the HTML output displayed on an invoice. Typically consists of an
 * HTML form that will take the user to the payment gateway endpoint.
 *
 * @param array $params Payment Gateway Module Parameters
 *
 * @see https://developers.whmcs.com/payment-gateways/third-party-gateway/
 *
 * @return string
 */
function morune_link($params) {
    $merchant_id = $params['merchant_id'];
    $secret_word = $params['secret_word'];

    $sum = $params['amount'];

    $invoice = $params['invoiceid'].'-'.time();

    $data = [
        'shop_id' => $merchant_id,
        'amount' => $sum,
        'currency' => $params['currency'],
        'order_id' => $invoice,
        'comment' => $params['description'],
    ];

    $url = "https://api.morune.com/invoice/create";

    // Инициализация cURL сессии
    $ch = curl_init($url);

    // Установка параметров cURL
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        'Accept: application/json',
        'x-api-key: ' . $secret_word,
    ]);

    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));

    $response = curl_exec($ch);

    curl_close($ch);

    $data = json_decode($response, true);

    return '<form method="GET" action="' . $data['data']['url'] . '"><input type="submit" value="'.$params['langpaynow'].'"></form>';
}